"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const hardhat_1 = __importDefault(require("hardhat"));
const data_json_1 = __importDefault(require("./data.json"));
const sdk_1 = require("@graphprotocol/sdk");
const ethers_1 = require("ethers");
async function main() {
    const graph = hardhat_1.default.graph();
    const deployer = await graph.getDeployer();
    // First estimate cost
    const gasEstimate = await data_json_1.default.data.subgraphs.reduce(async (acc, subgraph) => {
        return (await acc).add(await graph.contracts.L1GNS.connect(deployer).estimateGas.migrateLegacySubgraph(subgraph.owner.id, subgraph.subgraphNumber, subgraph.metadataHash));
    }, Promise.resolve(ethers_1.BigNumber.from(0)));
    const gasPrice = await graph.provider.getGasPrice();
    const cost = ethers_1.ethers.utils.formatEther(gasEstimate.mul(gasPrice));
    // Ask for confirmation
    if (!(await (0, sdk_1.confirm)(`This script will migrate ${data_json_1.default.data.subgraphs.length} legacy subgraphs, with an approximate cost of ${cost} Ξ. Are you sure you want to continue?`, false)))
        return;
    // do it
    for (const subgraph of data_json_1.default.data.subgraphs) {
        console.log(`Migrating legacy subgraph ${subgraph.owner.id}/${subgraph.subgraphNumber}...`);
        const legacyKey = await graph.contracts.L1GNS.legacySubgraphKeys((0, sdk_1.subgraphIdToHex)(subgraph.id));
        if (legacyKey.account !== ethers_1.ethers.constants.AddressZero) {
            console.log(`  - Already migrated, skipping`);
            continue;
        }
        try {
            const tx = await graph.contracts.L1GNS.connect(deployer).migrateLegacySubgraph(subgraph.owner.id, subgraph.subgraphNumber, subgraph.metadataHash);
            const receipt = await tx.wait();
            if (receipt.status == 1) {
                console.log(`   ✔ Migration succeeded!`);
            }
            else {
                console.log(`   ✖ Migration failed!`);
                console.log(receipt);
            }
        }
        catch (error) {
            console.log(error);
        }
    }
}
main().catch((error) => {
    console.error(error);
    process.exitCode = 1;
});
