"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_1 = require("@graphprotocol/sdk");
const hardhat_1 = __importDefault(require("hardhat"));
async function main() {
    const graph = hardhat_1.default.graph();
    const deployer = await graph.getDeployer();
    const [indexer] = await graph.getTestAccounts();
    console.log('Deployer:', deployer.address);
    console.log('Indexer:', indexer.address);
    const receipt = {
        requestCID: '0x8bec406793c8e1c5d4bd4e059833e95b7a9aeed6a118cbe335a79735836f9ff7',
        responseCID: '0xbdfc41643b5ff8d55f6cdb50f05575e1fdf177fa54d98cae1b9c76d8b360ff57',
        subgraphDeploymentID: '0xa3bfbfc6f53fd8a61b78e0b9a90c7fbe9ff290cba87b045bc476137fb2963cf9',
    };
    console.log('Receipt requestCID:', receipt.requestCID);
    console.log('Receipt response CID:', receipt.responseCID);
    console.log('Receipt subgraphDeploymentID:', receipt.subgraphDeploymentID);
    const indexerChannelKey = (0, sdk_1.deriveChannelKey)();
    console.log('Indexer channel key:', indexerChannelKey.address);
    console.log('Indexer channel key privKey:', indexerChannelKey.privKey);
    // Set up indexer
    await deployer.sendTransaction({ value: (0, sdk_1.toGRT)('0.05'), to: indexer.address });
    await graph.contracts.GraphToken.connect(deployer).transfer(indexer.address, (0, sdk_1.toGRT)('100000'));
    await (0, sdk_1.stake)(graph.contracts, indexer, { amount: (0, sdk_1.toGRT)('100000') });
    await (0, sdk_1.allocateFrom)(graph.contracts, indexer, {
        channelKey: indexerChannelKey,
        amount: (0, sdk_1.toGRT)('100000'),
        subgraphDeploymentID: receipt.subgraphDeploymentID,
    });
}
main().catch((error) => {
    console.error(error);
    process.exitCode = 1;
});
