"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gre_1 = require("@graphprotocol/sdk/gre");
const ethers_1 = require("ethers");
const console_table_printer_1 = require("console-table-printer");
const sdk_1 = require("@arbitrum/sdk");
const sdk_2 = require("@graphprotocol/sdk");
(0, gre_1.greTask)('bridge:deposits', 'List deposits initiated on L1GraphTokenGateway')
    .addOptionalParam('startBlock', 'Start block for the search')
    .addOptionalParam('endBlock', 'End block for the search')
    .setAction(async (taskArgs, hre) => {
    console.log('> L1GraphTokenGateway deposits');
    const graph = hre.graph(taskArgs);
    const gateway = graph.l1.contracts.L1GraphTokenGateway;
    console.log(`Tracking 'DepositInitiated' events on ${gateway.address}`);
    const startBlock = taskArgs.startBlock ? parseInt(taskArgs.startBlock) : 0;
    const endBlock = taskArgs.endBlock ? parseInt(taskArgs.endBlock) : 'latest';
    console.log(`Searching blocks from block ${startBlock} to block ${endBlock}`);
    const events = await Promise.all((await gateway.queryFilter(gateway.filters.DepositInitiated(), startBlock, endBlock)).map(async (e) => ({
        blockNumber: `${e.blockNumber} (${new Date((await graph.l1.provider.getBlock(e.blockNumber)).timestamp * 1000).toLocaleString()})`,
        tx: `${e.transactionHash} ${e.args.from} -> ${e.args.to}`,
        amount: ethers_1.ethers.utils.formatEther(e.args.amount),
        status: emojifyRetryableStatus(await (0, sdk_2.getL1ToL2MessageStatus)(e.transactionHash, graph.l1.provider, graph.l2.provider)),
    })));
    const total = events.reduce((acc, e) => acc.add(ethers_1.ethers.utils.parseEther(e.amount)), ethers_1.ethers.BigNumber.from(0));
    console.log(`Found ${events.length} deposits with a total of ${ethers_1.ethers.utils.formatEther(total)} GRT`);
    console.log('L1 to L2 message status reference: 🚧 = not yet created, ❌ = creation failed, ⚠️  = funds deposited on L2, ✅ = redeemed, ⌛ = expired');
    printEvents(events);
});
function printEvents(events) {
    const tablePrinter = new console_table_printer_1.Table({
        charLength: { '🚧': 2, '✅': 2, '⚠️': 1, '⌛': 2, '❌': 2 },
        columns: [
            { name: 'status', color: 'green', alignment: 'center' },
            { name: 'blockNumber', color: 'green', alignment: 'center' },
            {
                name: 'tx',
                color: 'green',
                alignment: 'center',
                maxLen: 88,
            },
            { name: 'amount', color: 'green', alignment: 'center' },
        ],
    });
    events.map(e => tablePrinter.addRow(e));
    tablePrinter.printTable();
}
function emojifyRetryableStatus(status) {
    switch (status) {
        case sdk_1.L1ToL2MessageStatus.NOT_YET_CREATED:
            return '🚧';
        case sdk_1.L1ToL2MessageStatus.CREATION_FAILED:
            return '❌';
        case sdk_1.L1ToL2MessageStatus.FUNDS_DEPOSITED_ON_L2:
            return '⚠️ ';
        case sdk_1.L1ToL2MessageStatus.REDEEMED:
            return '✅';
        case sdk_1.L1ToL2MessageStatus.EXPIRED:
            return '⌛';
        default:
            return '❌';
    }
}
