"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ethers_1 = require("ethers");
const console_table_printer_1 = require("console-table-printer");
const sdk_1 = require("@arbitrum/sdk");
const gre_1 = require("@graphprotocol/sdk/gre");
const sdk_2 = require("@graphprotocol/sdk");
(0, gre_1.greTask)('bridge:withdrawals', 'List withdrawals initiated on L2GraphTokenGateway')
    .addOptionalParam('startBlock', 'Start block for the search')
    .addOptionalParam('endBlock', 'End block for the search')
    .setAction(async (taskArgs, hre) => {
    console.log('> L2GraphTokenGateway withdrawals');
    const graph = hre.graph(taskArgs);
    const gateway = graph.l2.contracts.L2GraphTokenGateway;
    console.log(`Tracking 'WithdrawalInitiated' events on ${gateway.address}`);
    const startBlock = taskArgs.startBlock ? parseInt(taskArgs.startBlock) : 0;
    const endBlock = taskArgs.endBlock ? parseInt(taskArgs.endBlock) : 'latest';
    console.log(`Searching blocks from block ${startBlock} to block ${endBlock}`);
    const events = await Promise.all((await gateway.queryFilter(gateway.filters.WithdrawalInitiated(), startBlock, endBlock)).map(async (e) => ({
        blockNumber: `${e.blockNumber} (${new Date((await graph.l2.provider.getBlock(e.blockNumber)).timestamp * 1000).toLocaleString()})`,
        tx: `${e.transactionHash} ${e.args.from} -> ${e.args.to}`,
        amount: ethers_1.ethers.utils.formatEther(e.args.amount),
        status: emojifyL2ToL1Status(await (0, sdk_2.getL2ToL1MessageStatus)(e.transactionHash, graph.l1.provider, graph.l2.provider)),
    })));
    const total = events.reduce((acc, e) => acc.add(ethers_1.ethers.utils.parseEther(e.amount)), ethers_1.ethers.BigNumber.from(0));
    console.log(`Found ${events.length} withdrawals for a total of ${ethers_1.ethers.utils.formatEther(total)} GRT`);
    console.log('L2 to L1 message status reference: 🚧 = unconfirmed, ⚠️  = confirmed, ✅ = executed');
    printEvents(events);
});
function printEvents(events) {
    const tablePrinter = new console_table_printer_1.Table({
        charLength: { '🚧': 2, '✅': 2, '⚠️': 1, '❌': 2 },
        columns: [
            { name: 'status', color: 'green', alignment: 'center' },
            { name: 'blockNumber', color: 'green' },
            {
                name: 'tx',
                color: 'green',
                alignment: 'center',
                maxLen: 88,
            },
            { name: 'amount', color: 'green' },
        ],
    });
    events.map(e => tablePrinter.addRow(e));
    tablePrinter.printTable();
}
function emojifyL2ToL1Status(status) {
    switch (status) {
        case sdk_1.L2ToL1MessageStatus.UNCONFIRMED:
            return '🚧';
        case sdk_1.L2ToL1MessageStatus.CONFIRMED:
            return '⚠️ ';
        case sdk_1.L2ToL1MessageStatus.EXECUTED:
            return '✅';
        default:
            return '❌';
    }
}
