"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_1 = require("@graphprotocol/sdk");
const gre_1 = require("@graphprotocol/sdk/gre");
(0, gre_1.greTask)('contract:deploy', 'Deploy a contract')
    .addPositionalParam('contract', 'Name of the contract to deploy')
    .addOptionalPositionalParam('init', 'Initialization arguments for the contract constructor. Provide arguments as comma-separated values')
    .addParam('deployType', 'Choose deploy, deploy-save, deploy-with-proxy, deploy-with-proxy-save')
    .addFlag('skipConfirmation', 'Skip confirmation prompt on write actions')
    .addFlag('buildAcceptTx', '...')
    .setAction(async (taskArgs, hre) => {
    const graph = hre.graph(taskArgs);
    const deployer = await graph.getDeployer();
    if (!Object.values(sdk_1.DeployType).includes(taskArgs.deployType)) {
        throw new Error(`Deploy type ${taskArgs.deployType} not supported`);
    }
    console.log(`Deploying ${taskArgs.contract}...`);
    console.log(`Init: ${taskArgs.init}`);
    console.log(`Deploy type: ${taskArgs.deployType}`);
    console.log(`Deployer: ${deployer.address}`);
    console.log(`Chain ID: ${graph.chainId}`);
    const sure = await (0, sdk_1.confirm)(`Are you sure to deploy ${taskArgs.contract}?`, taskArgs.skipConfirmation);
    if (!sure)
        return;
    const deployment = await (0, sdk_1.deploy)(taskArgs.deployType, deployer, {
        name: taskArgs.contract,
        args: taskArgs.init?.split(',') || [],
    }, graph.addressBook);
    console.log(`Contract deployed at ${deployment.contract.address}`);
});
