"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gre_1 = require("@graphprotocol/sdk/gre");
const sdk_1 = require("@graphprotocol/sdk");
(0, gre_1.greTask)('contract:upgrade', 'Upgrades a contract')
    .addParam('contract', 'Name of the contract to upgrade')
    .addOptionalVariadicPositionalParam('init', 'Initialization arguments for the contract constructor')
    .setAction(async (taskArgs, hre) => {
    const graph = hre.graph(taskArgs);
    const { GraphProxyAdmin } = graph.contracts;
    const { governor } = await graph.getNamedAccounts();
    const deployer = await graph.getDeployer();
    const contract = graph.contracts[taskArgs.contract];
    if (!contract) {
        throw new Error(`Contract ${taskArgs.contract} not found in address book`);
    }
    console.log(`Upgrading ${taskArgs.contract}...`);
    // Deploy new implementation
    const { contract: implementation } = await (0, sdk_1.deploy)(sdk_1.DeployType.DeployImplementationAndSave, deployer, {
        name: taskArgs.contract,
        args: taskArgs.init || [],
    }, new sdk_1.GraphNetworkAddressBook(taskArgs.addressBook, graph.chainId));
    console.log(`New implementation deployed at ${implementation.address}`);
    // Upgrade proxy and accept implementation
    await GraphProxyAdmin.connect(governor).upgrade(contract.address, implementation.address);
    await GraphProxyAdmin.connect(governor).acceptProxy(implementation.address, contract.address);
    console.log(`Proxy upgraded to ${implementation.address}`);
});
