"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_1 = require("@graphprotocol/sdk");
const gre_1 = require("@graphprotocol/sdk/gre");
(0, gre_1.greTask)('update-config', 'Update graph config parameters with onchain data')
    .addFlag('dryRun', 'Only print the changes, don\'t write them to the config file')
    .addFlag('skipConfirmation', 'Skip confirmation prompt on write actions.')
    .setAction(async (taskArgs, hre) => {
    const networkName = hre.network.name;
    const configFile = taskArgs.graphConfig;
    const dryRun = taskArgs.dryRun;
    const skipConfirmation = taskArgs.skipConfirmation;
    console.log('## Update graph config ##');
    console.log(`Network: ${networkName}`);
    console.log(`Config file: ${configFile}\n`);
    // Prompt to avoid accidentally overwriting the config file with data from another network
    if (!configFile.includes(networkName)) {
        const sure = await (0, sdk_1.confirm)(`Config file ${configFile} doesn't match 'graph.<networkName>.yml'. Are you sure you want to continue?`, skipConfirmation);
        if (!sure)
            return;
    }
    const { graphConfig, contracts } = hre.graph({ graphConfig: configFile });
    // general parameters
    console.log(`> General`);
    for (const param of sdk_1.GraphNetworkConfigGeneralParams) {
        await (0, sdk_1.updateGeneralParams)(contracts, param, graphConfig);
    }
    // contracts parameters
    for (const contract of sdk_1.GraphNetworkConfigContractList) {
        console.log(`> ${contract.name}`);
        await (0, sdk_1.updateContractParams)(contracts, contract, graphConfig);
    }
    if (dryRun) {
        console.log('\n Dry run enabled, printing changes to console (no files updated)\n');
        console.log(graphConfig.toString());
    }
    else {
        (0, sdk_1.writeConfig)(configFile, graphConfig.toString());
    }
});
