"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("hardhat/config");
const types = __importStar(require("hardhat/internal/core/params/argumentTypes"));
const sourcify_1 = require("./sourcify");
const contract_names_1 = require("hardhat/utils/contract-names");
const task_names_1 = require("hardhat/builtin-tasks/task-names");
const gre_1 = require("@graphprotocol/sdk/gre");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const sdk_1 = require("@graphprotocol/sdk");
(0, config_1.task)('sourcify', 'Verifies contract on sourcify')
    .addPositionalParam('address', 'Address of the smart contract to verify', undefined, types.string)
    .addParam('contract', 'Fully qualified name of the contract to verify.', undefined, types.string)
    .setAction(async (args, hre) => {
    if (!(0, contract_names_1.isFullyQualifiedName)(args.contract)) {
        throw new Error('Invalid fully qualified name of the contract.');
    }
    const { contractName, sourceName: contractSource } = (0, contract_names_1.parseFullyQualifiedName)(args.contract);
    if (!fs_1.default.existsSync(contractSource)) {
        throw new Error(`Contract source ${contractSource} not found.`);
    }
    await hre.run(task_names_1.TASK_COMPILE);
    await (0, sourcify_1.submitSourcesToSourcify)(hre, {
        source: contractSource,
        name: contractName,
        address: args.address,
        fqn: args.contract,
    });
});
(0, gre_1.greTask)('sourcifyAll', 'Verifies all contracts on sourcify').setAction(async (_args, hre) => {
    const chainId = hre.network.config.chainId;
    const chainName = hre.network.name;
    if (!chainId || !chainName) {
        throw new Error('Cannot verify contracts without a network');
    }
    console.log(`> Verifying all contracts on chain ${chainName}[${chainId}]...`);
    const { addressBook } = hre.graph({ addressBook: _args.addressBook });
    for (const contractName of addressBook.listEntries()) {
        console.log(`\n> Verifying contract ${contractName}...`);
        const contractPath = getContractPath(contractName);
        if (contractPath) {
            const contract = addressBook.getEntry(contractName);
            if (contract.implementation) {
                console.log('Contract is upgradeable, verifying proxy...');
                await hre.run('sourcify', {
                    address: contract.address,
                    contract: 'contracts/upgrades/GraphProxy.sol:GraphProxy',
                });
            }
            // Verify implementation
            await hre.run('sourcify', {
                address: contract.implementation?.address ?? contract.address,
                contract: `${contractPath}:${contractName}`,
            });
        }
        else {
            console.log(`Contract ${contractName} not found.`);
        }
    }
});
(0, gre_1.greTask)('verifyAll', 'Verifies all contracts on etherscan').setAction(async (args, hre) => {
    const chainId = hre.network.config.chainId;
    const chainName = hre.network.name;
    if (!chainId || !chainName) {
        throw new Error('Cannot verify contracts without a network');
    }
    console.log(`> Verifying all contracts on chain ${chainName}[${chainId}]...`);
    const { addressBook, getDeployer } = hre.graph({
        addressBook: args.addressBook,
        graphConfig: args.graphConfig,
    });
    const graphConfig = (0, sdk_1.readConfig)(args.graphConfig, false);
    const deployer = (await getDeployer()).address;
    for (const contractName of addressBook.listEntries()) {
        console.log(`\n> Verifying contract ${contractName}...`);
        const contractConfig = (0, sdk_1.getContractConfig)(graphConfig, addressBook, contractName, deployer);
        const contractPath = getContractPath(contractName);
        const constructorParams = contractConfig.params.map(p => p.value.toString());
        if (contractPath) {
            const contract = addressBook.getEntry(contractName);
            if (contract.implementation) {
                console.log('Contract is upgradeable, verifying proxy...');
                const proxyAdmin = addressBook.getEntry('GraphProxyAdmin');
                // Verify proxy
                await safeVerify(hre, {
                    address: contract.address,
                    contract: 'contracts/upgrades/GraphProxy.sol:GraphProxy',
                    constructorArgsParams: [contract.implementation.address, proxyAdmin.address],
                });
            }
            // Verify implementation
            console.log('Verifying implementation...');
            await safeVerify(hre, {
                address: contract.implementation?.address ?? contract.address,
                contract: `${contractPath}:${contractName}`,
                constructorArgsParams: contract.implementation ? [] : constructorParams,
            });
        }
        else {
            console.log(`Contract ${contractName} not found.`);
        }
    }
});
// etherscan API throws errors if the contract is already verified
async function safeVerify(hre, taskArguments) {
    try {
        await hre.run('verify', taskArguments);
    }
    catch (error) {
        console.log(error.message);
    }
}
function getContractPath(contract) {
    const files = readDirRecursive('contracts/');
    return files.find(f => path_1.default.basename(f) === `${contract}.sol`);
}
function readDirRecursive(dir, allFiles = []) {
    const files = fs_1.default.readdirSync(dir);
    for (const file of files) {
        if (fs_1.default.statSync(path_1.default.join(dir, file)).isDirectory()) {
            allFiles = readDirRecursive(path_1.default.join(dir, file), allFiles);
        }
        else {
            allFiles.push(path_1.default.join(dir, file));
        }
    }
    return allFiles;
}
