"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const hardhat_1 = __importDefault(require("hardhat"));
require("@nomiclabs/hardhat-ethers");
const { ethers } = hardhat_1.default;
const { AddressZero } = ethers.constants;
describe('Governed', () => {
    const graph = hardhat_1.default.graph();
    let me;
    let governor;
    let governed;
    beforeEach(async function () {
        [me, governor] = await graph.getTestAccounts();
        const factory = await ethers.getContractFactory('GovernedMock');
        governed = (await factory.connect(governor).deploy());
    });
    it('should reject transfer if not allowed', async function () {
        const tx = governed.connect(me).transferOwnership(me.address);
        await (0, chai_1.expect)(tx).revertedWith('Only Governor can call');
    });
    it('should transfer and accept', async function () {
        // Transfer ownership
        const tx1 = governed.connect(governor).transferOwnership(me.address);
        await (0, chai_1.expect)(tx1).emit(governed, 'NewPendingOwnership').withArgs(AddressZero, me.address);
        // Reject accept if not the pending governor
        await (0, chai_1.expect)(governed.connect(governor).acceptOwnership()).revertedWith('Caller must be pending governor');
        // Accept ownership
        const tx2 = governed.connect(me).acceptOwnership();
        await (0, chai_1.expect)(tx2).emit(governed, 'NewOwnership').withArgs(governor.address, me.address);
        // Clean pending governor
        (0, chai_1.expect)(await governed.pendingGovernor()).eq(AddressZero);
    });
});
