"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetworkFixture = void 0;
const sdk_1 = require("@graphprotocol/sdk");
class NetworkFixture {
    constructor(provider) {
        this.provider = provider;
    }
    async load(deployer, l2Deploy) {
        return await (0, sdk_1.deployGraphNetwork)('./addresses-local.json', l2Deploy ? './config/graph.arbitrum-hardhat.yml' : './config/graph.hardhat.yml', 1337, deployer, this.provider, {
            governor: deployer,
            skipConfirmation: true,
            forceDeploy: true,
            l2Deploy: l2Deploy,
            enableTxLogging: false,
        });
    }
    async loadMock(l2Deploy) {
        return await (0, sdk_1.deployMockGraphNetwork)(l2Deploy);
    }
    async loadL1ArbitrumBridge(deployer) {
        return await sdk_1.helpers.deployL1MockBridge(deployer, 'arbitrum-addresses-local.json', this.provider);
    }
    async loadL2ArbitrumBridge(deployer) {
        return await sdk_1.helpers.deployL2MockBridge(deployer, 'arbitrum-addresses-local.json', this.provider);
    }
    async configureL1Bridge(deployer, l1FixtureContracts, l2MockContracts) {
        await (0, sdk_1.configureL1Bridge)(l1FixtureContracts, deployer, {
            l2GRTAddress: l2MockContracts.L2GraphToken.address,
            l2GRTGatewayAddress: l2MockContracts.L2GraphTokenGateway.address,
            l2GNSAddress: l2MockContracts.L2GNS.address,
            l2StakingAddress: l2MockContracts.L2Staking.address,
            arbAddressBookPath: './arbitrum-addresses-local.json',
            chainId: 1337,
        });
        await l1FixtureContracts.L1GraphTokenGateway.connect(deployer).setPaused(false);
    }
    async configureL2Bridge(deployer, l2FixtureContracts, l1MockContracts) {
        await (0, sdk_1.configureL2Bridge)(l2FixtureContracts, deployer, {
            l1GRTAddress: l1MockContracts.GraphToken.address,
            l1GRTGatewayAddress: l1MockContracts.L1GraphTokenGateway.address,
            l1GNSAddress: l1MockContracts.L1GNS.address,
            l1StakingAddress: l1MockContracts.L1Staking.address,
            arbAddressBookPath: './arbitrum-addresses-local.json',
            chainId: 412346,
        });
        await l2FixtureContracts.L2GraphTokenGateway.connect(deployer).setPaused(false);
    }
    async setUp() {
        this.lastSnapshot = await sdk_1.helpers.takeSnapshot();
    }
    async tearDown() {
        await sdk_1.helpers.restoreSnapshot(this.lastSnapshot);
    }
}
exports.NetworkFixture = NetworkFixture;
